#!/usr/bin/env python3
import sys
import os
import random
import string
import shutil

MAXN = MAXM = MAXW = MAXP = 100000
cases = [["oneMonger", 10, 10], ["minDemand", 10, 1]]
cases.extend([["random", 10, 10] for _ in range(3)])
cases.extend([["random", MAXN, MAXM] for _ in range(4)])
cases.append(["maxAll", MAXN, MAXM])


def main():
    dir_path = os.path.dirname(os.path.realpath(__file__))
    if os.getcwd() != dir_path:
        print("Not in correct directory, aborting")
        sys.exit()
    
    print("removing old secret test data")
    shutil.rmtree("data/secret", ignore_errors=True)
    os.makedirs("data/secret")

    print("generating cases...")
    for i, case in enumerate(cases):
        print("generating case {:02d}".format(i + 1))
        
        res = generate(case, i)
        
        file_prefix = "data/secret/{:02d}".format(i + 1)
        with open(file_prefix + ".in", "w") as f:
            f.write(res+"\n")
            
        ans = solve(res)
        with open(file_prefix + ".ans", "w") as f:
            f.write(ans+"\n")
        
                #
        # case_lines = []
        # n_max, m_max = case
        # random.seed(i)
        # n = random.randint(1, n_max)
        # m = random.randint(1, m_max)
        # case_lines.append("%d %d" % (n, m))
        # fish_kind = set()
        # for _ in xrange(n):
        #     fish_name = random_name(32)
        #     fish_price = random.randint(1, 200000)
        #     case_lines.append("%s %d" % (fish_name, fish_price))
        #     fish_kind.add(fish_name)
        #
        # for _ in xrange(m):
        #     k = random.randint(2, min(n, 30))
        #     case_lines.append(str(k))
        #     num_existing_fish = random.randint(k // 2, min(k, len(fish_kind)))
        #     fish_to_use = random.sample(fish_kind, num_existing_fish)
        #     for fish in fish_to_use:
        #         case_lines.append("%s %d" % (fish, random.randint(1, 200000)))
        #     for _ in xrange(k - num_existing_fish):
        #         case_lines.append("%s %d" % (random_name(32), random.randint(1, 200000)))
        #
        # case_lines.append("")
        
        
def generate(options, seed):
    random.seed(seed)
    strategy, n, m = options
    if strategy == "oneMonger":
        weights = [str(random.randint(1, 10)) for _ in range(n)]
        mongers = [[1, 1] for _ in range(m-1)] + [[n, 2]]
        random.shuffle(mongers)
        return "{} {}\n".format(n, m) + " ".join(weights) + "\n" + "\n".join(["{} {}".format(c, p) for c, p in mongers])
    
    if strategy == "minDemand":
        weights = [str(random.randint(1, 10)) for _ in range(n)]
        mongers = [[1, 1] for _ in range(m)]
        return "{} {}\n".format(n, m) + " ".join(weights) + "\n" + "\n".join(["{} {}".format(c, p) for c, p in mongers])
        
    if strategy == "maxAll":
        weights = [str(MAXW) for _ in range(n)]
        mongers = [[MAXN, MAXP] for _ in range(m)]
        return "{} {}\n".format(n, m) + " ".join(weights) + "\n" + "\n".join(["{} {}".format(c, p) for c, p in mongers])
    
    if strategy == "random":
        weights = [str(random.randint(1, n)) for _ in range(n)]
        mongers = [[random.randint(1, 5), random.randint(1, MAXP)] for _ in range(m)]
        return "{} {}\n".format(n, m) + " ".join(weights) + "\n" + "\n".join(["{} {}".format(c, p) for c, p in mongers])

def solve(inp):
    inp = inp.split("\n")
    n, m = [int(x) for x in inp[0].split()]
    fish = sorted([int(x) for x in inp[1].split()])
    shops = sorted([[int(x) for x in y.split()] for y in inp[2:]], key=lambda x: x[1])
    
    earnings = 0
    while len(fish) > 0 and len(shops) > 0:
        weight = fish.pop()
        earnings += weight * shops[-1][1]
        shops[-1][0] -= 1
        if shops[-1][0] == 0:
            shops.pop()
            
    return str(earnings)
    

if __name__ == '__main__':
    main()


