from __future__ import print_function, division
class SegTree:
    def __init__(self, values):
        self.maps = dict()
        i = 2
        while i <= 2*len(values) + 10:
            i *= 2
        self.offset = i // 2 + 5
        self.subtree = [0 for _ in xrange(i)]
        self.segCov = [0 for _ in xrange(i)]
        self.lenSeg = [0 for _ in xrange(i)]
        self.vals = list(values)
        for j in xrange(len(self.vals)):
            self.maps[self.vals[j]] = j + self.offset
            if j+1 < len(self.vals):
                self.lenSeg[j+self.offset] = self.vals[j+1] - self.vals[j]
        for j in xrange( (i//2 - 1), 0, -1):
            self.lenSeg[j] = self.lenSeg[2*j] + self.lenSeg[2*j+1]
    
    def covered(self):
        if self.segCov[1] > 0:
            return self.lenSeg[1]
        return self.subtree[1]
    
    def add(self,low, high):
        l = self.maps[low]-1
        r = self.maps[high]
        dl = 0
        dr = 0
        while True:
            nl = l // 2
            nr = r // 2
            if nl == nr:
                break
            tmp = 2*nl
            if tmp == l:
                self.segCov[tmp + 1] += 1
                if self.segCov[tmp + 1] == 1:
                    dl += self.lenSeg[tmp + 1] - self.subtree[tmp + 1]
            tmp = 2 * nr
            if tmp + 1 == r:
                self.segCov[tmp] += 1
                if self.segCov[tmp] == 1:
                    dr += self.lenSeg[tmp] - self.subtree[tmp]
            
            self.subtree[nl] += dl
            self.subtree[nr] += dr
            if self.segCov[nl] > 0:
                dl = 0
            if self.segCov[nr] > 0:
                dr = 0
            l = nl
            r = nr
        l = l // 2
        d = dl + dr
        while l > 0:
            self.subtree[l] += d
            if self.segCov[l] > 0:
                d = 0
            l //= 2
    
    def remove(self,low, high):
        l = self.maps[low]-1
        r = self.maps[high]
        dl = 0
        dr = 0
        while True:
            nl = l // 2
            nr = r // 2
            if nl == nr:
                break
            tmp = 2*nl
            if tmp == l:
                self.segCov[tmp + 1] -= 1
                if self.segCov[tmp + 1] == 0:
                    dl -= self.lenSeg[tmp + 1] - self.subtree[tmp + 1]
            tmp = 2 * nr
            if tmp + 1 == r:
                self.segCov[tmp] -= 1
                if self.segCov[tmp] == 0:
                    dr -= self.lenSeg[tmp] - self.subtree[tmp]
            
            self.subtree[nl] += dl
            self.subtree[nr] += dr
            if self.segCov[nl] > 0:
                dl = 0
            if self.segCov[nr] > 0:
                dr = 0
            l = nl
            r = nr
        l = l // 2
        d = dl + dr
        while l > 0:
            self.subtree[l] += d
            if self.segCov[l] > 0:
                d = 0
            l //= 2

def main():
    n = int(raw_input())
    rects = [0 for _ in xrange(2*n)]
    y_vals = []
    y_vals.append(0)
    y_vals.append(1<<50)
    for i in xrange(n):
        x0,y0,x1,y1 = (int(x) for x in raw_input().split())
        rects[2*i] = (y0,y1,x0, True)
        rects[2*i+1] = (y0,y1,x1, False)
        y_vals.append(y0)
        y_vals.append(y1)
    
    rects.sort(key = lambda y: y[2])
    y_vals.sort()

    lastX = rects[0][2]
    area = 0
    st = SegTree(y_vals)
    for rect in rects:
        area += (rect[2] - lastX) * st.covered()
        if rect[3]:
            st.add(rect[0], rect[1])
        else:
            st.remove(rect[0], rect[1])
        lastX = rect[2]
    print(area)

main()

