import java.util.*;
import java.io.*;
import java.util.StringTokenizer;

public class GameMap {
    private static class Kattio extends PrintWriter {
        public Kattio(InputStream i) {
            super(new BufferedOutputStream(System.out));
            r = new BufferedReader(new InputStreamReader(i));
        }
        public Kattio(InputStream i, OutputStream o) {
            super(new BufferedOutputStream(o));
            r = new BufferedReader(new InputStreamReader(i));
        }

        public boolean hasMoreTokens() {
            return peekToken() != null;
        }

        public int getInt() {
            return Integer.parseInt(nextToken());
        }

        public double getDouble() {
            return Double.parseDouble(nextToken());
        }

        public long getLong() {
            return Long.parseLong(nextToken());
        }

        public String getWord() {
            return nextToken();
        }


        private BufferedReader r;
        private String line;
        private StringTokenizer st;
        private String token;

        private String peekToken() {
            if (token == null)
                try {
                    while (st == null || !st.hasMoreTokens()) {
                        line = r.readLine();
                        if (line == null) return null;
                        st = new StringTokenizer(line);
                    }
                    token = st.nextToken();
                } catch (IOException e) { }
            return token;
        }

        private String nextToken() {
            String ans = peekToken();
            token = null;
            return ans;
        }
    }

    private static class Event {
        private int ind, type;

        public Event(int ind, int type) {
            this.ind = ind;
            this.type = type;
        }
    }

    private static class Point {
        private int x, y;

        public Point(int x, int y) {
            this.x = x;
            this.y = y;
        }

        @Override
        public String toString() {
            return "(" + x + ", " + y + ")";
        }

        static double angle(Point a, Point b, Point c) {
            return (b.x - a.x) * (c.y - a.y) - (c.x - a.x) * (b.y - a.y);
        }
    }

    static Point[] ps;
    static Point[][] rects;
    static Event[] events_h, events_v;
    static int N, E;

    public static void main(String[] args) {
        Kattio io = new Kattio(System.in);

        E = 0;
        N = io.getInt(); // # of rectangles
        ps = new Point[4 * N];
        events_v = new Event[2*N];
        events_h = new Event[2*N];

        rects = new Point[N][2];

        int cnt = 0;

        for (int i = 0; i < N; i++) {
            int x1 = io.getInt(), y1 = io.getInt();
            ps[cnt++] = new Point(x1, y1);

            int x2 = io.getInt(), y2 = io.getInt();
            ps[cnt++] = new Point(x2, y2);

            ps[cnt++] = new Point(x1, y2); // upper left
            ps[cnt++] = new Point(x2, y1); // lower right

            rects[i][0] = new Point(x1, y1);
            rects[i][1] = new Point(x2, y2);

            events_v[E] = new Event(i, 0);
            events_h[E++] = new Event(i, 0);
            events_v[E] = new Event(i, 1);
            events_h[E++] = new Event(i, 1);
        }


        // Calculate area of convex hull
        Stack<Point> hull = convexHull();
        double hullArea = 0;
        for (int j = 1; j < hull.size(); j++) {
            double d = hull.get(j-1).x * hull.get(j).y - hull.get(j-1).y*hull.get(j).x;
            hullArea += d;
        }

        hullArea += hull.get(hull.size()-1).x * hull.get(0).y - hull.get(hull.size()-1).y * hull.get(0).x;
        hullArea = Math.abs(hullArea)/2;


        // Calculate area of rectangles
        double rectangleArea = union(events_h, events_v);

        System.out.println(hullArea-rectangleArea);
}

    static Stack<Point> convexHull() {
        int min = 0;
        for (int i = 1; i <  ps.length; i++) {
            if (ps[i].y < ps[min].y || (ps[i].y == ps[min].y && ps[i].x < ps[min].x)) {
                min = i;
            }
        }

        Point temp = ps[0];
        ps[0] = ps[min];
        ps[min] = temp;

        Stack<Point> hull = new Stack<>();


        hull.push(ps[0]);
        Arrays.sort(ps, 1, ps.length, (p1, p2) -> Integer.compare((p1.x - ps[0].x) * (p2.y - ps[0].y), (p2.x - ps[0].x) * (p1.y - ps[0].y)));

        hull.push(ps[1]);
        hull.push(ps[2]);

        for (int i = 3; i < ps.length; i++) {
            Point top = hull.peek();
            Point next = hull.get(hull.size() - 2);

            while (Point.angle(ps[i], next, top) >= 0 && hull.size() > 2) {
                hull.pop();
                top = hull.peek();
                next = hull.get(hull.size() - 2);
            }

            hull.push(ps[i]);
        }

        return hull;
    }

    public static double union(Event[] events_h, Event[] events_v) {
        boolean[] inSet = new boolean[N];
        double area = 0;

        Arrays.sort(events_v, Comparator.comparingDouble(a -> rects[a.ind][a.type].x));
        Arrays.sort(events_h, Comparator.comparingDouble(a -> rects[a.ind][a.type].y));

        inSet[events_v[0].ind] = true;

        for (int i = 1; i < E; i++) {
            Event c = events_v[i];

            int delta_x = rects[c.ind][c.type].x - rects[events_v[i-1].ind][events_v[i-1].type].x;

            if (delta_x == 0){
                inSet[c.ind] = (c.type == 0);
                continue;
            }

            int cnt = 0;
            int begin_y = 0;
            for (int j = 0; j < E; j++) {
                if (inSet[events_h[j].ind]) {
                    if (events_h[j].type == 0) {
                        if (cnt++ == 0) {
                            begin_y = rects[events_h[j].ind][0].y;
                        }
                    } else {
                        if (--cnt == 0) {
                            double delta_y = rects[events_h[j].ind][1].y - begin_y;
                            area += delta_x * delta_y;
                        }
                    }
                }
            }

            inSet[c.ind] = (c.type == 0);
        }
        return area;
    }
}
