from __future__ import absolute_import, division, print_function
import sys
from Queue import PriorityQueue

class Component(object):
    def __init__(self, free, tot):
        self.free = free
        self.tot = tot
    
    # ordering that sorts in descending value of "connectivity",
    # preferring free connection spots over total potential
    # except of (1, 1) - components which create unconnectable
    # components if merged (they are ordered last)
    def __lt__(self, other):
        if self.tot == 1:
            return False
        if other.tot == 1:
            return True
        if self.free > other.free:
            return True
        if other.free > self.free:
            return False
        return True if self.tot > other.tot else False


def find_cc_caps(adj, constraints):
    n = len(adj)
    visited = [False] * n
    ccs = []
    for i in xrange(n):
        if visited[i]:
            continue
        stack = [i]
        comp_free = 0
        comp_edges = 0
        comp_size = 0
        while len(stack) > 0:
            u = stack.pop()
            if visited[u]:
                continue
            visited[u] = True
            comp_size += 1
            comp_edges += len(adj[u])
            comp_free += constraints[u] - len(adj[u])
            for v in adj[u]:
                if not visited[v]:
                    stack.append(v)
        comp_edges /= 2
        ccs.append((comp_free, comp_free + 2 * (comp_edges - comp_size + 1)))
    return ccs


def main():
    n, m, k = (int(x) for x in sys.stdin.readline().split())
    constraints = [int(x) for x in sys.stdin.readline().split()]

    adj = [[] for _ in xrange(n)]
    for _ in xrange(m):
        u, v = (int(x) for x in sys.stdin.readline().split())
        adj[u].append(v)
        adj[v].append(u)
    
    ccs = find_cc_caps(adj, constraints)
    if len(ccs) == 1:
        print("yes")
        sys.exit()

    # fix (0, 0) components
    ccs_fixed = PriorityQueue()

    for tot, free in ccs:
        if tot == 0 and free == 0:
            # this is a necessary split
            k -= 1
            ccs_fixed.put(Component(1, 1))
            ccs_fixed.put(Component(1, 1))
        else:
            ccs_fixed.put(Component(tot, free))

    # The following solution gradually connects components
    # using edge deletions only when neccessary
    while ccs_fixed.qsize() > 1 and k > 0:
        cc1 = ccs_fixed.get()
        cc2 = ccs_fixed.get()
        c1_free = cc1.free
        c1_tot = cc1.tot
        c2_free = cc2.free
        c2_tot = cc2.tot

        # impossible to create connections
        if c1_tot == 0 or c2_tot == 0:
            print("no")
            sys.exit()

        # we must free up a cycle edge, using an edit
        if c1_free == 0:
            c1_free += 2
            k -= 1
        if c2_free == 0:
            c2_free += 2
            k -= 1
        
        # we merge the two components, using a single edit
        k -= 1
        ccs_fixed.put(Component(c1_free + c2_free - 2, c1_tot + c2_tot - 2))
    if ccs_fixed.qsize() > 1 or k < 0:
        print("no")
    else:
        print("yes")


if __name__ == '__main__':
    main()
